/*
 * BEGIN_HEADER - DO NOT EDIT
 * 
 * The contents of this file are subject to the terms
 * of the Common Development and Distribution License
 * (the "License").  You may not use this file except
 * in compliance with the License.
 *
 * You can obtain a copy of the license at
 * https://open-jbi-components.dev.java.net/public/CDDLv1.0.html.
 * See the License for the specific language governing
 * permissions and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL
 * HEADER in each file and include the License file at
 * https://open-jbi-components.dev.java.net/public/CDDLv1.0.html.
 * If applicable add the following below this CDDL HEADER,
 * with the fields enclosed by brackets "[]" replaced with
 * your own identifying information: Portions Copyright
 * [year] [name of copyright owner]
 */

/*
 * @(#)Reply.java
 *
 * Copyright 2004-2007 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * END_HEADER - DO NOT EDIT
 */
package org.glassfish.openesb.pojose.api.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Designates a call back method when the outstanding response messages from 
 * other ServiceEndoints are recieved.
 * 
 * Valid method signature return void and have one or 2 input parameters.
 * When only one method is annotated with this, it should have 2 input parameter.
 * First one being ServiceEndpoint, second one of the String, Node, Source, 
 * NormalizedMessage and MessageExchange.
 * 
 * One can have more than one OnReply call back methods, provided all of them 
 * uses single input parameter of type String, Node, Source, 
 * NormalizedMessage and MessageExchange. And also property "endpoint" value 
 * corresponds to valid ServiceEndpoint member variable.
 * 
 */

@Target(ElementType.METHOD)
@Retention(RetentionPolicy.RUNTIME)
public @interface OnReply {
    /**
     * Valid for single input parameter method. 
     * Value corresponds to the ServiceEndpoint member variable name.
     */
    public String endpoint()  default "";
}